==> risk-center-api-0.5.5-20190718.022823-4-sources.jar: cn/com/duiba/tuia/risk/center/api/dto/ImageUrl.java <==
package cn.com.duiba.tuia.risk.center.api.dto;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;

/**
 * 广告素材&落地页URL
 */
@ApiModel
public class ImageUrl implements Serializable {

    private static final long serialVersionUID = 995957376479357292L;

    @ApiModelProperty("广告素材URL")
    private String advertUrl;

    @ApiModelProperty("素材描述")
    private String advertDesc;

    @ApiModelProperty("落地页URL")
    private String lanPageUrl;

    @ApiModelProperty("发券次序：指本轮巡查中，第几次出现")
    private Integer patrolOrder;

    @ApiModelProperty("出现次数")
    private Integer findCount;

    @ApiModelProperty("素材热度")
    private Double heatPercent;

    @ApiModelProperty("行业标记id")
    private Long signId;

    @ApiModelProperty("行业id")
    private Long industryId;

    public String getAdvertUrl() {
        return advertUrl;
    }

    public void setAdvertUrl(String advertUrl) {
        this.advertUrl = advertUrl;
    }

    public String getAdvertDesc() {
        return advertDesc;
    }

    public void setAdvertDesc(String advertDesc) {
        this.advertDesc = advertDesc;
    }

    public String getLanPageUrl() {
        return lanPageUrl;
    }

    public void setLanPageUrl(String lanPageUrl) {
        this.lanPageUrl = lanPageUrl;
    }

    public Integer getPatrolOrder() {
        return patrolOrder;
    }

    public void setPatrolOrder(Integer patrolOrder) {
        this.patrolOrder = patrolOrder;
    }

    public Integer getFindCount() {
        return findCount;
    }

    public void setFindCount(Integer findCount) {
        this.findCount = findCount;
    }

    public Double getHeatPercent() {
        return heatPercent;
    }

    public void setHeatPercent(Double heatPercent) {
        this.heatPercent = heatPercent;
    }

    public Long getSignId() {
        return signId;
    }

    public void setSignId(Long signId) {
        this.signId = signId;
    }

    public Long getIndustryId() {
        return industryId;
    }

    public void setIndustryId(Long industryId) {
        this.industryId = industryId;
    }
}

==> risk-center-api-0.5.5-20190724.110701-6-sources.jar: cn/com/duiba/tuia/risk/center/api/dto/ImageUrl.java <==
package cn.com.duiba.tuia.risk.center.api.dto;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;

/**
 * 广告素材&落地页URL
 */
@ApiModel
public class ImageUrl implements Serializable {

    private static final long serialVersionUID = 995957376479357292L;

    @ApiModelProperty("广告素材URL")
    private String advertUrl;

    @ApiModelProperty("素材描述")
    private String advertDesc;

    @ApiModelProperty("落地页URL")
    private String lanPageUrl;

    @ApiModelProperty("发券次序：指本轮巡查中，第几次出现")
    private Integer patrolOrder;

    @ApiModelProperty("出现次数")
    private Integer findCount;

    @ApiModelProperty("素材热度")
    private Double heatPercent;

    @ApiModelProperty("行业标记id")
    private Long signId;

    @ApiModelProperty("行业id")
    private Long industryId;

    @ApiModelProperty("竞品日志id")
    private Long logId;

    public String getAdvertUrl() {
        return advertUrl;
    }

    public void setAdvertUrl(String advertUrl) {
        this.advertUrl = advertUrl;
    }

    public String getAdvertDesc() {
        return advertDesc;
    }

    public void setAdvertDesc(String advertDesc) {
        this.advertDesc = advertDesc;
    }

    public String getLanPageUrl() {
        return lanPageUrl;
    }

    public void setLanPageUrl(String lanPageUrl) {
        this.lanPageUrl = lanPageUrl;
    }

    public Integer getPatrolOrder() {
        return patrolOrder;
    }

    public void setPatrolOrder(Integer patrolOrder) {
        this.patrolOrder = patrolOrder;
    }

    public Integer getFindCount() {
        return findCount;
    }

    public void setFindCount(Integer findCount) {
        this.findCount = findCount;
    }

    public Double getHeatPercent() {
        return heatPercent;
    }

    public void setHeatPercent(Double heatPercent) {
        this.heatPercent = heatPercent;
    }

    public Long getSignId() {
        return signId;
    }

    public void setSignId(Long signId) {
        this.signId = signId;
    }

    public Long getIndustryId() {
        return industryId;
    }

    public void setIndustryId(Long industryId) {
        this.industryId = industryId;
    }

    public Long getLogId() {
        return logId;
    }

    public void setLogId(Long logId) {
        this.logId = logId;
    }
}
